use strict;
use warnings;

package Dist::Zilla::MintingProfile::DistIller::Basic;

our $VERSION = '0.1202'; # VERSION

use Moose;
with 'Dist::Zilla::Role::MintingProfile::ShareDir';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Dist::Zilla::MintingProfile::DistIller::Basic

=head1 VERSION

Version 0.1202, released 2015-11-27.

=head1 SOURCE

L<https://github.com/Csson/p5-Dist-Iller>

=head1 HOMEPAGE

L<https://metacpan.org/release/Dist-Iller>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
